# Generated by Django 3.2.13 on 2022-08-26 01:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0046_auto_20220826_0322"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="endofstudy",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalendofstudy",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicallosstofollowup",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicaloffschedule",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicaloffschedulepostnatal",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicaloffschedulepregnancy",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicaloffstudymedication",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalpregnancynotification",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalprotocolincident",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalsubjecttransfer",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="losstofollowup",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="offschedule",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="offschedulepostnatal",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="offschedulepregnancy",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="offstudymedication",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="pregnancynotification",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="protocolincident",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="subjecttransfer",
            name="tracking_identifier",
        ),
    ]
