# Generated by Django 3.2.13 on 2022-09-13 18:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0148_auto_20220908_1826"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="order_or_update_next",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Order, or update, refill for next scheduled visit?",
            ),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="order_or_update_next",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Order, or update, refill for next scheduled visit?",
            ),
        ),
    ]
