# Generated by Django 3.2.11 on 2022-04-14 14:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0105_auto_20220412_2310"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="pill_count",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Number of pills left in the bottle"
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="pill_count",
            field=models.IntegerField(
                blank=True, null=True, verbose_name="Number of pills left in the bottle"
            ),
        ),
    ]
