# Generated by Django 3.0.6 on 2020-05-30 15:19

import edc_visit_tracking.managers
from django.db import migrations

import meta_subject.models.subject_visit


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0046_auto_20200530_1804"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectvisit",
            managers=[
                ("on_site", edc_visit_tracking.managers.VisitCurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.VisitModelManager()),
            ],
        ),
    ]
