# Generated by Django 3.0.6 on 2020-06-13 17:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0048_auto_20200530_1819"),
    ]

    operations = []
