# Generated by Django 3.0.4 on 2020-04-19 20:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0023_auto_20200419_2305"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coronakap",
            name="family_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>someone in your family</u> will get sick from coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="hot_climate",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus does not survive in the hot climate",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="know_other_symptoms",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Do you know of any other symptoms of coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="lives_on_materials",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus can live on clothes, plastics, cardboard for a day or more",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="personal_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>you</u> will get sick from coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="severity_age",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus is more severe in older people than children",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="severity_diabetes_hypertension",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus is more severe in people with <u>diabetes</u> and/or <u>hypertension</u>",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="severity_hiv",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus is more severe in people with <u>HIV infection</u>",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_asymptomatic",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit coronavirus even when they do not appear to be sick",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_droplets",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus spreads by droplets from cough and sneezes from people infected with coronavirus",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_sick",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit coronavirus when they are sick ",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_touch",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus can spread by people touching each other",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="spread_touch2",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="You can catch coronavirus if you touch an infected area and then touch your face or eyes",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="stop_chronic_meds",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                help_text="For example, medicines for diabetes, hypertension and/or HIV",
                max_length=25,
                verbose_name="Stop taking your chronic disease medicines",
            ),
        ),
        migrations.AlterField(
            model_name="coronakap",
            name="symptoms_other",
            field=models.TextField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="Please list any other symptoms of coronavirus that you are aware of:",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="family_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>someone in your family</u> will get sick from coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="hot_climate",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus does not survive in the hot climate",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="know_other_symptoms",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Do you know of any other symptoms of coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="lives_on_materials",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus can live on clothes, plastics, cardboard for a day or more",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="personal_infection_likelihood",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                max_length=25,
                verbose_name="How likely do you think it is that <u>you</u> will get sick from coronavirus?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="severity_age",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus is more severe in older people than children",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="severity_diabetes_hypertension",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus is more severe in people with <u>diabetes</u> and/or <u>hypertension</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="severity_hiv",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus is more severe in people with <u>HIV infection</u>",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_asymptomatic",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit coronavirus even when they do not appear to be sick",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_droplets",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus spreads by droplets from cough and sneezes from people infected with coronavirus",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_sick",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="People can transmit coronavirus when they are sick ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_touch",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="Coronavirus can spread by people touching each other",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="spread_touch2",
            field=models.CharField(
                choices=[
                    ("true", "True"),
                    ("false", "False"),
                    ("dont_know", "Don't know"),
                ],
                max_length=25,
                verbose_name="You can catch coronavirus if you touch an infected area and then touch your face or eyes",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="stop_chronic_meds",
            field=models.CharField(
                choices=[
                    ("very", "Very likely"),
                    ("somewhat", "Somewhat likely"),
                    ("unlikely", "Not very likely, unlikely"),
                    ("not_at_all", "Not at all"),
                ],
                help_text="For example, medicines for diabetes, hypertension and/or HIV",
                max_length=25,
                verbose_name="Stop taking your chronic disease medicines",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcoronakap",
            name="symptoms_other",
            field=models.TextField(
                blank=True,
                max_length=250,
                null=True,
                verbose_name="Please list any other symptoms of coronavirus that you are aware of:",
            ),
        ),
    ]
