# Generated by Django 2.2.7 on 2020-01-20 19:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0018_auto_20200118_1854"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="unsuitable_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=5,
                verbose_name="Does the study coordinator agree that the patient is not suitable for the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="unsuitable_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=5,
                verbose_name="Does the study coordinator agree that the patient is not suitable for the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="unsuitable_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=5,
                verbose_name="Does the study coordinator agree that the patient is not suitable for the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="unsuitable_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=5,
                verbose_name="Does the study coordinator agree that the patient is not suitable for the study?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="unsuitable_agreed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=5,
                verbose_name="Does the study coordinator agree that the patient is not suitable for the study?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                max_length=150,
                null=True,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                max_length=150,
                null=True,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                max_length=150,
                null=True,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                max_length=150,
                null=True,
                verbose_name="Reason not suitable for the study",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="reasons_unsuitable",
            field=models.TextField(
                blank=True,
                max_length=150,
                null=True,
                verbose_name="Reason not suitable for the study",
            ),
        ),
    ]
