# Generated by Django 3.2.13 on 2022-09-06 22:57

import uuid

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0143_auto_20220826_0406"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalstudymedication",
            old_name="order_next",
            new_name="order_or_update_next",
        ),
        migrations.RenameField(
            model_name="studymedication",
            old_name="order_next",
            new_name="order_or_update_next",
        ),
        migrations.RenameField(
            model_name="historicalstudymedication",
            old_name="refill_date",
            new_name="refill_start_datetime",
        ),
        migrations.RenameField(
            model_name="studymedication",
            old_name="refill_date",
            new_name="refill_start_datetime",
        ),
    ]
