# Generated by Django 4.1.2 on 2022-10-05 18:37

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0155_auto_20220929_1742"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result assay date and time",
            ),
        ),
    ]
