# Generated by Django 3.2.11 on 2022-04-12 20:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0104_auto_20220412_2151"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstudymedication",
            name="refill_date",
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="refill_date",
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="order_next",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Order refill for next scheduled visit?",
            ),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="order_next",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Order refill for next scheduled visit?",
            ),
        ),
    ]
