# Generated by Django 2.2.7 on 2020-01-18 15:54

import edc_vitals.models.fields.blood_pressure
import edc_vitals.models.fields.weight
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0010_auto_20191213_0314"),
    ]

    operations = [
        migrations.AlterField(
            model_name="followupvitals",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="followupvitals",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="followupvitals",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="dia_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.DiastolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="sys_blood_pressure",
            field=edc_vitals.models.fields.blood_pressure.SystolicPressureField(null=True),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="weight",
            field=edc_vitals.models.fields.weight.WeightField(),
        ),
    ]
