# Generated by Django 2.2.6 on 2019-11-04 22:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("meta_screening", "0008_auto_20191031_0745")]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="selection_method",
            field=models.CharField(
                choices=[
                    ("random_sampling", "Random sampling"),
                    ("purposively_selected", "Purposively selected"),
                ],
                default="?",
                max_length=25,
                verbose_name="How was the patient selected from the outpatients CTC?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="selection_method",
            field=models.CharField(
                choices=[
                    ("random_sampling", "Random sampling"),
                    ("purposively_selected", "Purposively selected"),
                ],
                default="?",
                max_length=25,
                verbose_name="How was the patient selected from the outpatients CTC?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="selection_method",
            field=models.CharField(
                choices=[
                    ("random_sampling", "Random sampling"),
                    ("purposively_selected", "Purposively selected"),
                ],
                default="?",
                max_length=25,
                verbose_name="How was the patient selected from the outpatients CTC?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="selection_method",
            field=models.CharField(
                choices=[
                    ("random_sampling", "Random sampling"),
                    ("purposively_selected", "Purposively selected"),
                ],
                default="?",
                max_length=25,
                verbose_name="How was the patient selected from the outpatients CTC?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="continue_part_two",
            field=models.CharField(
                choices=[("Yes", "Yes (default)"), ("No", "No")],
                default="Yes",
                help_text="<B>Important</B>: This response will be be automatically set to YES if:<BR><BR>- the participant meets the eligibility criteria for part one;<BR><BR>- the eligibility criteria for part two is already complete.<BR>",
                max_length=15,
                verbose_name="Continue with <U>part two</U> of the screening process?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="selection_method",
            field=models.CharField(
                choices=[
                    ("random_sampling", "Random sampling"),
                    ("purposively_selected", "Purposively selected"),
                ],
                default="?",
                max_length=25,
                verbose_name="How was the patient selected from the outpatients CTC?",
            ),
            preserve_default=False,
        ),
    ]
