# Generated by Django 3.2.13 on 2022-09-29 14:42

from django.db import migrations, models
import edc_action_item.managers
import edc_model.validators.date
import edc_protocol.validators
import edc_sites.models
import edc_utils.date


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0048_auto_20220922_2236"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="endofstudy",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="losstofollowup",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedule",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedulepostnatal",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedulepregnancy",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="offstudymedication",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="pregnancynotification",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="protocolincident",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="offstudy_datetime",
            field=models.DateTimeField(
                default=edc_utils.date.get_utcnow,
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Off-study date and time",
            ),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="report_datetime",
            field=models.DateTimeField(editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="offstudy_datetime",
            field=models.DateTimeField(
                default=edc_utils.date.get_utcnow,
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Off-study date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="report_datetime",
            field=models.DateTimeField(editable=False, null=True),
        ),
    ]
