# Generated by Django 3.2.13 on 2022-09-06 22:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("edc_adverse_event", "0009_auto_20220907_0157"),
        ("meta_ae", "0014_auto_20220826_0406"),
    ]

    operations = [
        migrations.AddField(
            model_name="aeinitial",
            name="ae_action_classification",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_adverse_event.aeactionclassification",
                verbose_name="Classification of action taken",
            ),
        ),
        migrations.AddField(
            model_name="historicalaeinitial",
            name="ae_action_classification",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_adverse_event.aeactionclassification",
                verbose_name="Classification of action taken",
            ),
        ),
    ]
