# Generated by Django 3.2.13 on 2022-09-25 02:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0151_auto_20220918_0508"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "site", "panel", "id"],
                name="meta_subjec_subject_2bb98e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "report_datetime"],
                name="meta_subjec_subject_c4a56c_idx",
            ),
        ),
    ]
