# Generated by Django 3.2.13 on 2022-07-08 18:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0121_auto_20220704_1841"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="pill_count_not_performed_reason",
            field=models.TextField(
                blank=True, null=True, verbose_name="If not performed, please explain ..."
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="pill_count_not_performed_reason",
            field=models.TextField(
                blank=True, null=True, verbose_name="If not performed, please explain ..."
            ),
        ),
    ]
