# Generated by Django 4.0.5 on 2022-06-27 14:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0046_historicalscreeningpartone_hba1c_datetime_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="appt_datetime_repeat",
            field=models.DateTimeField(
                blank=True,
                help_text="must be at least 3 days after the first glucose measures (FBG, OGTT)",
                null=True,
                verbose_name="Appointment date for repeat glucose testing",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="appt_datetime_repeat",
            field=models.DateTimeField(
                blank=True,
                help_text="must be at least 3 days after the first glucose measures (FBG, OGTT)",
                null=True,
                verbose_name="Appointment date for repeat glucose testing",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="appt_datetime_repeat",
            field=models.DateTimeField(
                blank=True,
                help_text="must be at least 3 days after the first glucose measures (FBG, OGTT)",
                null=True,
                verbose_name="Appointment date for repeat glucose testing",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="appt_datetime_repeat",
            field=models.DateTimeField(
                blank=True,
                help_text="must be at least 3 days after the first glucose measures (FBG, OGTT)",
                null=True,
                verbose_name="Appointment date for repeat glucose testing",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="appt_datetime_repeat",
            field=models.DateTimeField(
                blank=True,
                help_text="must be at least 3 days after the first glucose measures (FBG, OGTT)",
                null=True,
                verbose_name="Appointment date for repeat glucose testing",
            ),
        ),
    ]
