# Generated by Django 3.0.4 on 2020-04-03 00:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0003_auto_20200120_2020"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="loss_category",
            field=models.CharField(
                choices=[], max_length=25, verbose_name="Category of loss to follow up"
            ),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="loss_category",
            field=models.CharField(
                choices=[], max_length=25, verbose_name="Category of loss to follow up"
            ),
        ),
    ]
