# Generated by Django 2.2.7 on 2019-12-13 00:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0009_auto_20191119_2331"),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomics",
            old_name="transport",
            new_name="transport_old",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomics",
            old_name="transport",
            new_name="transport_old",
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="buy_meds_month",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Over the last month, did you get any drugs or have a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="childcare_source_timeoff",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                null=True,
                verbose_name="How much time did a family member, friend take off work to look after your child or children?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="diabetic_expenditure_month",
            field=models.IntegerField(
                blank=True,
                editable=False,
                help_text="in Shilling",
                null=True,
                verbose_name="If YES, how much did you spend on Diabetic drugs",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="diabetic_payee",
            field=models.CharField(
                choices=[
                    ("own_cash", "Own cash"),
                    ("insurance", "Insurance"),
                    ("relative", "Relative of others paying"),
                    ("free", "Free drugs from the pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                editable=False,
                max_length=15,
                verbose_name="If YES, how did you pay or who paid for these drugs",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="higher_education",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Did you go to higher education?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="off_work_days",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                verbose_name="How much time did you take off work?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="routine_activities",
            field=models.CharField(
                choices=[
                    ("working", "Working"),
                    ("studying", "Studying"),
                    ("caring_for_children", "Caring for children"),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="What would you be doing if you had not come to the hospital?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="buy_meds_month",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Over the last month, did you get any drugs or have a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="childcare_source_timeoff",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                null=True,
                verbose_name="How much time did a family member, friend take off work to look after your child or children?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="diabetic_expenditure_month",
            field=models.IntegerField(
                blank=True,
                editable=False,
                help_text="in Shilling",
                null=True,
                verbose_name="If YES, how much did you spend on Diabetic drugs",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="diabetic_payee",
            field=models.CharField(
                choices=[
                    ("own_cash", "Own cash"),
                    ("insurance", "Insurance"),
                    ("relative", "Relative of others paying"),
                    ("free", "Free drugs from the pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                editable=False,
                max_length=15,
                verbose_name="If YES, how did you pay or who paid for these drugs",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="higher_education",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Did you go to higher education?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="off_work_days",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in days. (1,2,3 etc. If half-day 0.5)",
                max_digits=4,
                verbose_name="How much time did you take off work?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="routine_activities",
            field=models.CharField(
                choices=[
                    ("working", "Working"),
                    ("studying", "Studying"),
                    ("caring_for_children", "Caring for children"),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="What would you be doing if you had not come to the hospital?",
            ),
        ),
    ]
