# Generated by Django 2.2.6 on 2019-10-21 00:53

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("meta_screening", "0004_auto_20191020_0738")]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="waist_circumference",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="height",
            field=models.DecimalField(
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(100.0),
                    django.core.validators.MaxValueValidator(230.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="urine_bhcg_performed",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="N/A",
                help_text="(Pregnancy test)",
                max_length=15,
                verbose_name="Was a Urine or serum βhCG performed?",
            ),
        ),
    ]
