# Generated by Django 3.2.13 on 2022-09-29 14:42

import django.contrib.sites.managers
from django.db import migrations
import edc_identifier.managers
import meta_consent.models.subject_consent


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0016_auto_20220914_0547"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectconsent",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", meta_consent.models.subject_consent.SubjectConsentManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="subjectreconsent",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_identifier.managers.SubjectIdentifierManager()),
            ],
        ),
    ]
