# Generated by Django 3.2.11 on 2022-04-15 14:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0108_auto_20220415_1747"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="refill_date",
            field=models.DateField(),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="refill_date",
            field=models.DateField(),
        ),
    ]
