# Generated by Django 3.2.9 on 2021-11-23 13:45

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0028_auto_20210823_2353"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="aou",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Using META3 approved assessment tool. This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Have the research staff assessed the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="aou_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on assessing the subject's understanding of the study?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="aou_passed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="This response is not criteria for eligibility",
                max_length=15,
                verbose_name="Based on the META3 approved assessment tool, has the subject demonstrated sufficient understanding of the study to continue?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="diet_and_lifestyle",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="This response is not criteria for eligibility",
                max_length=15,
                null=True,
                verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="diet_and_lifestyle_duration",
            field=models.IntegerField(
                help_text="Report in minutes. This response is not criteria for eligibility",
                null=True,
                verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="fasting_opinion",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("not_sure", "Not sure")],
                max_length=15,
                null=True,
                verbose_name="In the opinion of the clinican, has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="meta_phase_two",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the subject enrolled in the META Phase 2 trial?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="real_eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to now",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="eligibility_datetime",
            field=models.DateTimeField(
                editable=False,
                help_text="Date and time eligibility was determined relative to report_datetime",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="As reported by patient",
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting_duration_str",
            field=models.CharField(
                blank=True,
                help_text="As reported by patient. Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
    ]
