# Generated by Django 3.2.11 on 2022-04-15 14:47

import edc_action_item.models.action_model_mixin
import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0022_auto_20220318_0133"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="losstofollowup",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedule",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
                (
                    "on_site",
                    edc_sites.models.CurrentSiteManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedulepostnatal",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
                (
                    "on_site",
                    edc_sites.models.CurrentSiteManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="offschedulepregnancy",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
                (
                    "on_site",
                    edc_sites.models.CurrentSiteManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="pregnancynotification",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
        migrations.AlterModelManagers(
            name="protocoldeviationviolation",
            managers=[
                (
                    "objects",
                    edc_action_item.models.action_model_mixin.ActionIdentifierModelManager(),
                ),
            ],
        ),
    ]
