# Generated by Django 3.2.11 on 2022-03-12 16:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0037_auto_20220312_0339"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="repeat_fbg_performed",
            new_name="fbg2_performed",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg2_quantifier",
            new_name="fbg2_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg2_value",
            new_name="fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg_datetime",
            new_name="fbg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="repeat_ogtt_performed",
            new_name="ogtt2_performed",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg2_datetime",
            new_name="fbg2_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="repeat_fbg_performed",
            new_name="fbg2_performed",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg2_quantifier",
            new_name="fbg2_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg2_value",
            new_name="fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg_datetime",
            new_name="fbg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="repeat_ogtt_performed",
            new_name="ogtt2_performed",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg2_datetime",
            new_name="fbg2_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="repeat_fbg_performed",
            new_name="fbg2_performed",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg2_quantifier",
            new_name="fbg2_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg2_value",
            new_name="fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg_datetime",
            new_name="fbg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="repeat_ogtt_performed",
            new_name="ogtt2_performed",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg2_datetime",
            new_name="fbg2_datetime",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="repeat_fbg_performed",
            new_name="fbg2_performed",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg2_quantifier",
            new_name="fbg2_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg2_value",
            new_name="fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg_datetime",
            new_name="fbg_datetime",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="repeat_ogtt_performed",
            new_name="ogtt2_performed",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg2_datetime",
            new_name="fbg2_datetime",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="repeat_fbg_performed",
            new_name="fbg2_performed",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg2_quantifier",
            new_name="fbg2_quantifier",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg2_value",
            new_name="fbg2_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg_datetime",
            new_name="fbg_datetime",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="repeat_ogtt_performed",
            new_name="ogtt2_performed",
        ),
        migrations.RenameField(
            model_name="historicalicpreferral",
            old_name="ifg_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="converted_ifg2_value",
            new_name="converted_fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="converted_ifg_value",
            new_name="converted_fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg2_datetime",
            new_name="fbg2_datetime",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartone",
            old_name="ifg2_units",
            new_name="fbg2_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="converted_ifg2_value",
            new_name="converted_fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="converted_ifg_value",
            new_name="converted_fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningpartthree",
            old_name="ifg2_units",
            new_name="fbg2_units",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="converted_ifg2_value",
            new_name="converted_fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="converted_ifg_value",
            new_name="converted_fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalscreeningparttwo",
            old_name="ifg2_units",
            new_name="fbg2_units",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="converted_ifg2_value",
            new_name="converted_fbg2_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="converted_ifg_value",
            new_name="converted_fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="ifg2_units",
            new_name="fbg2_units",
        ),
        migrations.RenameField(
            model_name="icpreferral",
            old_name="ifg_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="converted_ifg2_value",
            new_name="converted_fbg2_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="converted_ifg_value",
            new_name="converted_fbg_value",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="ifg2_units",
            new_name="fbg2_units",
        ),
    ]
