# Generated by Django 3.2.13 on 2022-08-26 00:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_ae", "0012_auto_20220826_0258"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aefollowup",
            name="tracking_identifier",
            field=models.CharField(max_length=32, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="tracking_identifier",
            field=models.CharField(max_length=32, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="tracking_identifier",
            field=models.CharField(max_length=32, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="tracking_identifier",
            field=models.CharField(max_length=32, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="tracking_identifier",
            field=models.CharField(max_length=32, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="tracking_identifier",
            field=models.CharField(max_length=32, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32, null=True),
        ),
    ]
