# Generated by Django 3.2.4 on 2021-07-02 01:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0021_auto_20210628_2105"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ifg_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="A `HIGH` reading may be entered as 9999.99",
                max_digits=8,
                null=True,
                verbose_name="IFG level",
            ),
        ),
    ]
