# Generated by Django 3.2.13 on 2022-09-14 02:18

import edc_visit_tracking.managers
from django.db import migrations

import meta_consent.models.subject_consent


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0013_auto_20220826_0406"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectconsent",
            managers=[
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
                ("objects", meta_consent.models.subject_consent.SubjectConsentManager()),
            ],
        ),
    ]
